RasterizableCurve

Trait RasterizableCurve 

pub trait RasterizableCurve<S: Scalar> {
    // Required method
    fn eval_at(&self, t: S) -> GeopResult<Vector3<S>>;
}
Trait for objects that can be uniformly sampled into 3D points for rendering.

Required Methods

fn eval_at(&self, t: S) -> GeopResult<Vector3<S>>

Evaluate the curve at parameter t and return a 3D point.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors